pub struct Object {
pub mesh: Arc<Mesh>,
pub shadow: bool,
pub irradiance_volume: bool,
pub trans: Mat4,
pub chamber_index: ChamberIndex,
}Fields
mesh: Arc<Mesh>The mesh to render.
shadow: boolWhether to count in the shadow phase or not.
irradiance_volume: boolWhether to count in the irradiance volume phase or not.
trans: Mat4The model transformation.
chamber_index: ChamberIndexThe index of the chamber this object belongs to